{% extends "_base.html" %} {% load i18n %} {% load widget_tweaks %} {% block content %}

# {% translate "Release notes" %}

{% for year, versions in release_notes.items %} {% for version, notes in versions.items %} {% if version == "unreleased" %}

## {% translate "Unreleased" %}

{% else %}

## {{ version }}

{% endif %} {% include "release_notes/version.html" %} {% endfor %} {% endfor %}
{% endblock content %}